'use strict';
//Require dependencies
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');
var path = require('path');
var _ = require('lodash');
var extend = require('deep-extend');
var mkdirp = require('mkdirp');

module.exports = yeoman.Base.extend({
	initializing: function () {
    	this.props = {};
  	},
  	constructor: function () {
		yeoman.Base.apply(this, arguments);
	},
	//Configurations will be loaded here.
	//Ask for user input
	prompting: function() {
	  var done = this.async();

	  	this.log(yosay(
	      	'Welcome to the luminous ' + chalk.red('generator-web-metrocss') + ' generator!'
	   	));

	  	var prompts = [{
	        	type: 'input',
	        	name: 'name',
	        	message: 'Please input project name (web_metrocss):',
	        	default: 'web_metrocss'
	      	},
	     	{
	        	type: 'input',
	        	name: 'desc',
	        	message: 'Please input project description:'
	      	},
	      	{
	        	type: 'input',
	        	name: 'main',
	        	message: 'Main file (main.js):',
	        	default: 'main.js'
	      	},
	      	{
	        	type: 'input',
	        	name: 'author',
	        	message: 'Author (user):',
	        	default: 'user'
	      	},
	      	{
	        	type: 'list',
	        	name: 'license',
	        	message: 'Please choose license:',
	        	choices: ['MIT', 'ISC'],
	        	default: 'ISC'
	      	},
	      	{
	        	type: 'input',
	        	name: 'homepage',
	        	message: 'Please input homepage:'
	      	}];
	    return this.prompt(prompts).then(function (props) {
	      	this.props = props;
	      	done();
	    }.bind(this));
	},
	writing: {
		mkdir: function(){
			mkdirp(this.props.name);
		},
		gulpfile: function () {
			this.fs.copy(
				this.templatePath('_gulpfile.js'),
				this.destinationPath(this.props.name+'/gulpfile.js')				
			);
		},

		packageJSON: function () {
			this.fs.copyTpl(
				this.templatePath('_package.json'),
				this.destinationPath(this.props.name+'/package.json'),
				{
					name: this.props.name,
	              	desc: this.props.desc,
	              	main: this.props.main,
	              	author: this.props.author,
	              	license: this.props.license,
	              	homepage: this.props.homepage,
				}
			);
		},

		/*babel: function () {
			this.fs.copy(
				this.templatePath('babelrc'),
				this.destinationPath(this.props.name+'/.babelrc')
			);
		},*/
		bower: function(){
			this.fs.copyTpl(
	          	this.templatePath('_bower.json'),
	          	this.destinationPath(this.props.name+'/bower.json'), {
	              	name: this.props.name
	          	}
	      	);
		},
		mainFlie:function(){
			this.fs.copy(
				this.templatePath('_main.js'),
				this.destinationPath(this.props.name+'/res/js/main.js')				
			);
			this.fs.copy(
				this.templatePath('_main.css'),
				this.destinationPath(this.props.name+'/res/css/main.css')				
			);
			this.fs.copy(
				this.templatePath('_index.html'),
				this.destinationPath(this.props.name+'/res/html/index.html')				
			);
			mkdirp(this.props.name+"/res/img");
		}
	},
	install: function () {
        var done = this.async();
        this.spawnCommand('npm', ['install'])  //安装项目依赖
            .on('exit', function (code) {
                if (code) {
                    done(new Error('code:' + code));
                } else {
                    done();
                }
            })
            .on('error', done);
    }/*,
    end: function () {
        var done = this.async();
        this.spawnCommand('gulp')   //生成器退出前运行gulp，开启watch任务
            .on('exit', function (code) {
                if (code) {
                    done(new Error('code:' + code));
                } else {
                    done();
                }
            })
            .on('error', done);
    }*/
});


